"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Vimeo = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeWebview = require("react-native-webview");

var _template = _interopRequireDefault(require("./template"));

var _types = require("./types");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Vimeo = _ref => {
  let {
    type,
    videoId,
    onReady,
    onPlay,
    onPlayProgress,
    onPause,
    onFinish,
    scalesPageToFit,
    loop,
    controls,
    autoPlay,
    speed = false,
    style,
    onVolumeChange,
    onError,
    containerStyle,
    getVimeoPlayer,
    time
  } = _ref;
  const [initTime] = (0, _react.useState)(time ?? '0m0s');
  const [isPlaying, setPlaying] = (0, _react.useState)(false);
  const ref = (0, _react.useRef)();
  const [autoPlayValue, setAutoPlay] = (0, _react.useState)(autoPlay);
  const muted = _reactNative.Platform.OS === 'android' && autoPlayValue;
  const toggleAutoPlay = (0, _react.useCallback)(() => setAutoPlay(!autoPlayValue), [autoPlayValue]);
  const handlers = {};
  const player = (0, _react.useCallback)(action => {
    var _ref$current;

    const handler = ref === null || ref === void 0 ? void 0 : (_ref$current = ref.current) === null || _ref$current === void 0 ? void 0 : _ref$current.injectJavaScript;

    if (handler) {
      switch (action.type) {
        case _types.PlayerEvents.PLAY:
          if (isPlaying) return;
          handler('play();');
          setPlaying(true);
          break;

        case _types.PlayerEvents.PAUSE:
          if (!isPlaying) return;
          handler('await pause();');
          setPlaying(false);
          break;

        case _types.PlayerEvents.SET_TIME:
          handler(`setTime(${action.time});`);
          break;

        case _types.PlayerEvents.GET_DURATION:
          handler(`
            const videoDuration = getDuration();
            const callback = ${action.callback};
            callback(videoDuration);
          `);
          break;

        default:
          break;
      }
    }
  }, [ref, isPlaying]);
  const onReadyDefault = (0, _react.useCallback)(() => {
    onReady && setTimeout(onReady);
  }, [onReady]);
  const registerHandlers = (0, _react.useCallback)(() => {
    registerBridgeEventHandler('ready', onReadyDefault);
    registerBridgeEventHandler('play', onPlay);
    registerBridgeEventHandler('playProgress', onPlayProgress);
    registerBridgeEventHandler('pause', onPause);
    registerBridgeEventHandler('finish', onFinish);
    registerBridgeEventHandler('volumeChange', onVolumeChange);
    registerBridgeEventHandler('error', onError);
  }, [onReadyDefault, onPlay, onPlayProgress, onError, onVolumeChange, onPause, onFinish]);

  const registerBridgeEventHandler = (eventName, handler) => {
    handlers[eventName] = handler;
  };

  (0, _react.useEffect)(() => {
    registerHandlers();
  }, [videoId, scalesPageToFit]);
  const onBridgeMessage = (0, _react.useCallback)(event => {
    var _payload2, _payload3;

    const message = event.nativeEvent.data;
    let payload;

    try {
      var _payload;

      payload = JSON.parse(message);

      if (((_payload = payload) === null || _payload === void 0 ? void 0 : _payload.name) === 'finish') {
        toggleAutoPlay();
      }
    } catch (err) {
      return;
    }

    let bridgeMessageHandler = handlers[(_payload2 = payload) === null || _payload2 === void 0 ? void 0 : _payload2.name];
    if (bridgeMessageHandler) bridgeMessageHandler((_payload3 = payload) === null || _payload3 === void 0 ? void 0 : _payload3.data);
  }, [toggleAutoPlay, handlers]);
  (0, _react.useEffect)(() => {
    getVimeoPlayer && getVimeoPlayer(player);
  }, [getVimeoPlayer, player]);
  return /*#__PURE__*/_react.default.createElement(_reactNativeWebview.WebView, {
    allowsFullscreenVideo: true,
    source: {
      html: (0, _template.default)(type, videoId, loop, autoPlayValue, controls, speed, muted, initTime)
    },
    javaScriptEnabled: true,
    ref: ref,
    onMessage: onBridgeMessage,
    bounces: false,
    scrollEnabled: false,
    scalesPageToFit: scalesPageToFit,
    onError: error => console.error(error),
    style: [{
      marginTop: -8,
      marginLeft: -10
    }, style],
    containerStyle: containerStyle,
    setBuiltInZoomControls: false,
    setDisplayZoomControls: false,
    automaticallyAdjustContentInsets: true,
    onNavigationStateChange: a => console.log(a === null || a === void 0 ? void 0 : a.url)
  });
};

exports.Vimeo = Vimeo;
//# sourceMappingURL=index.js.map