import React, { useCallback, useEffect, useRef, useState } from 'react';
import { Platform } from 'react-native';
import { WebView } from 'react-native-webview';
import webplayer from './template';
import { PlayerEvents } from './types';
export const Vimeo = _ref => {
  let {
    type,
    videoId,
    onReady,
    onPlay,
    onPlayProgress,
    onPause,
    onFinish,
    scalesPageToFit,
    loop,
    controls,
    autoPlay,
    speed = false,
    style,
    onVolumeChange,
    onError,
    containerStyle,
    getVimeoPlayer,
    time
  } = _ref;
  const [initTime] = useState(time ?? '0m0s');
  const [isPlaying, setPlaying] = useState(false);
  const ref = useRef();
  const [autoPlayValue, setAutoPlay] = useState(autoPlay);
  const muted = Platform.OS === 'android' && autoPlayValue;
  const toggleAutoPlay = useCallback(() => setAutoPlay(!autoPlayValue), [autoPlayValue]);
  const handlers = {};
  const player = useCallback(action => {
    var _ref$current;

    const handler = ref === null || ref === void 0 ? void 0 : (_ref$current = ref.current) === null || _ref$current === void 0 ? void 0 : _ref$current.injectJavaScript;

    if (handler) {
      switch (action.type) {
        case PlayerEvents.PLAY:
          if (isPlaying) return;
          handler('play();');
          setPlaying(true);
          break;

        case PlayerEvents.PAUSE:
          if (!isPlaying) return;
          handler('await pause();');
          setPlaying(false);
          break;

        case PlayerEvents.SET_TIME:
          handler(`setTime(${action.time});`);
          break;

        case PlayerEvents.GET_DURATION:
          handler(`
            const videoDuration = getDuration();
            const callback = ${action.callback};
            callback(videoDuration);
          `);
          break;

        default:
          break;
      }
    }
  }, [ref, isPlaying]);
  const onReadyDefault = useCallback(() => {
    onReady && setTimeout(onReady);
  }, [onReady]);
  const registerHandlers = useCallback(() => {
    registerBridgeEventHandler('ready', onReadyDefault);
    registerBridgeEventHandler('play', onPlay);
    registerBridgeEventHandler('playProgress', onPlayProgress);
    registerBridgeEventHandler('pause', onPause);
    registerBridgeEventHandler('finish', onFinish);
    registerBridgeEventHandler('volumeChange', onVolumeChange);
    registerBridgeEventHandler('error', onError);
  }, [onReadyDefault, onPlay, onPlayProgress, onError, onVolumeChange, onPause, onFinish]);

  const registerBridgeEventHandler = (eventName, handler) => {
    handlers[eventName] = handler;
  };

  useEffect(() => {
    registerHandlers();
  }, [videoId, scalesPageToFit]);
  const onBridgeMessage = useCallback(event => {
    var _payload2, _payload3;

    const message = event.nativeEvent.data;
    let payload;

    try {
      var _payload;

      payload = JSON.parse(message);

      if (((_payload = payload) === null || _payload === void 0 ? void 0 : _payload.name) === 'finish') {
        toggleAutoPlay();
      }
    } catch (err) {
      return;
    }

    let bridgeMessageHandler = handlers[(_payload2 = payload) === null || _payload2 === void 0 ? void 0 : _payload2.name];
    if (bridgeMessageHandler) bridgeMessageHandler((_payload3 = payload) === null || _payload3 === void 0 ? void 0 : _payload3.data);
  }, [toggleAutoPlay, handlers]);
  useEffect(() => {
    getVimeoPlayer && getVimeoPlayer(player);
  }, [getVimeoPlayer, player]);
  return /*#__PURE__*/React.createElement(WebView, {
    allowsFullscreenVideo: true,
    source: {
      html: webplayer(type, videoId, loop, autoPlayValue, controls, speed, muted, initTime)
    },
    javaScriptEnabled: true,
    ref: ref,
    onMessage: onBridgeMessage,
    bounces: false,
    scrollEnabled: false,
    scalesPageToFit: scalesPageToFit,
    onError: error => console.error(error),
    style: [{
      marginTop: -8,
      marginLeft: -10
    }, style],
    containerStyle: containerStyle,
    setBuiltInZoomControls: false,
    setDisplayZoomControls: false,
    automaticallyAdjustContentInsets: true,
    onNavigationStateChange: a => console.log(a === null || a === void 0 ? void 0 : a.url)
  });
};
//# sourceMappingURL=index.js.map